@@ -407,7 +407,7 @@ def _df_to_bq_table(
         .option("project", "emart-datafabric")
         .option("credentials", base64.b64encode(key.encode()).decode())
         .option("table", table)
-        .option("temporaryGcsBucket", "temp-seoul-7d")
+        .option("temporaryGcsBucket", "emart-datafabric-temp-7d")
     )
     if partition_field:
         df = df.option("partitionField", partition_field)
